@@ -156,13 +156,23 @@ setMethod("[", c("ShortReadQ", "ANY", "ANY"),
           function(x, i, j, ..., drop=NA) .subset_err())
 
 .ShortReadQ_subset <- function(x, i, j, ..., drop=TRUE) {
-    if (0L != length(list(...))) .subset_err()
+    if (!missing(...)) .subset_err()
     initialize(x, sread=sread(x)[i], id=id(x)[i],
                quality=quality(x)[i])
 }
 
 setMethod("[", c("ShortReadQ", "ANY", "missing"), .ShortReadQ_subset)
 
+setReplaceMethod("[", c("ShortReadQ", "ANY", "missing", "ShortReadQ"),
+    function(x, i, j, ..., value)
+{
+    sread <- sread(x); sread[i] <- sread(value)
+    quality <- quality(quality(x)); quality[i] <- quality(quality(value))
+    id <- id(x); id[i] <- id(value)
+    initialize(x, sread=sread, id=id,
+               quality=initialize(quality(x), quality=quality))
+})
+
 setMethod(append, c("ShortReadQ", "ShortReadQ"),
     function(x, values, after=length(x))
 {
